@@ -13,21 +13,14 @@ set -o pipefail
 cd "${ROOT_DIR}"
 
 # This controls the knative release version we track.
-KN_VERSION="release-0.22"
-EVENTING_VERSION="release-v0.22.0"
-EVENTING_KAFKA_VERSION="release-v0.22.0"
-SERVING_VERSION="release-v0.22.0"
-
-# Controls the version of OCP related dependencies.
-OCP_VERSION="release-4.7"
+KN_VERSION="release-0.23"
+EVENTING_VERSION="release-v0.23"
+EVENTING_KAFKA_VERSION="release-v0.23"
+SERVING_VERSION="release-v0.23.1"
 
 # The list of dependencies that we track at HEAD and periodically
 # float forward in this repository.
 FLOATING_DEPS=(
-  "github.com/openshift/api@${OCP_VERSION}"
-  "github.com/openshift/client-go@${OCP_VERSION}"
-  "github.com/operator-framework/operator-lifecycle-manager@${OCP_VERSION}"
-
   "knative.dev/hack@${KN_VERSION}"
   "knative.dev/networking@${KN_VERSION}"
   "knative.dev/operator@${KN_VERSION}"
@@ -76,3 +69,6 @@ find vendor/ \( -name "OWNERS" \
   -o -name "*_test.go" \) -exec rm -fv {} +
 
 find vendor -type f -name '*.sh' -exec chmod +x {} +
+
+# SRVKE-669: Remove pingsource from HA
+git apply "$ROOT_DIR/hack/001-remove-pingsource-ha.patch"
