@@ -9,6 +9,7 @@ import (
 	mf "github.com/manifestival/manifestival"
 	operatorv1alpha1 "github.com/openshift-knative/serverless-operator/knative-operator/pkg/apis/operator/v1alpha1"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/monitoring"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
@@ -38,7 +39,7 @@ var (
 	role              = mf.Any(mf.ByKind("ClusterRole"), mf.ByKind("Role"))
 	rolebinding       = mf.Any(mf.ByKind("ClusterRoleBinding"), mf.ByKind("RoleBinding"))
 	roleOrRoleBinding = mf.Any(role, rolebinding)
-	KafkaHAComponents = []string{"kafka-ch-controller", "kafka-webhook", "kafka-controller-manager"}
+	KafkaHAComponents = []string{"kafka-ch-controller", "kafka-controller-manager"}
 )
 
 type stage func(*mf.Manifest, *operatorv1alpha1.KnativeKafka) error
@@ -65,11 +66,17 @@ func newReconciler(mgr manager.Manager) (*ReconcileKnativeKafka, error) {
 		return nil, fmt.Errorf("failed to load KafkaSource manifest: %w", err)
 	}
 
+	kafkaSourcePostInstallManifest, err := mf.ManifestFrom(mf.Path(os.Getenv("KAFKA_POST_INSTALL_MANIFEST_PATH")))
+	if err != nil {
+		return nil, fmt.Errorf("failed to load KafkaChannel Post Install manifest: %w", err)
+	}
+
 	reconcileKnativeKafka := ReconcileKnativeKafka{
-		client:                  mgr.GetClient(),
-		scheme:                  mgr.GetScheme(),
-		rawKafkaChannelManifest: kafkaChannelManifest,
-		rawKafkaSourceManifest:  kafkaSourceManifest,
+		client:                            mgr.GetClient(),
+		scheme:                            mgr.GetScheme(),
+		rawKafkaChannelManifest:           kafkaChannelManifest,
+		rawKafkaSourceManifest:            kafkaSourceManifest,
+		rawKafkaSourcePostInstallManifest: kafkaSourcePostInstallManifest,
 	}
 	return &reconcileKnativeKafka, nil
 }
@@ -107,10 +114,11 @@ var _ reconcile.Reconciler = &ReconcileKnativeKafka{}
 type ReconcileKnativeKafka struct {
 	// This client, initialized using mgr.Client() above, is a split client
 	// that reads objects from the cache and writes to the apiserver
-	client                  client.Client
-	scheme                  *runtime.Scheme
-	rawKafkaChannelManifest mf.Manifest
-	rawKafkaSourceManifest  mf.Manifest
+	client                            client.Client
+	scheme                            *runtime.Scheme
+	rawKafkaChannelManifest           mf.Manifest
+	rawKafkaSourceManifest            mf.Manifest
+	rawKafkaSourcePostInstallManifest mf.Manifest
 }
 
 // Reconcile reads that state of the cluster for a KnativeKafka object and makes changes based on the state read
@@ -147,11 +155,11 @@ func (r *ReconcileKnativeKafka) Reconcile(ctx context.Context, request reconcile
 		}
 	}
 
-	common.KnativeKafkaUpG = common.KnativeUp.WithLabelValues("kafka_status")
+	monitoring.KnativeKafkaUpG = monitoring.KnativeUp.WithLabelValues("kafka_status")
 	if instance.Status.IsReady() {
-		common.KnativeKafkaUpG.Set(1)
+		monitoring.KnativeKafkaUpG.Set(1)
 	} else {
-		common.KnativeKafkaUpG.Set(0)
+		monitoring.KnativeKafkaUpG.Set(0)
 	}
 	return reconcile.Result{}, reconcileErr
 }
@@ -228,7 +236,7 @@ func (r *ReconcileKnativeKafka) ensureFinalizers(_ *mf.Manifest, instance *opera
 
 func (r *ReconcileKnativeKafka) transform(manifest *mf.Manifest, instance *operatorv1alpha1.KnativeKafka) error {
 	log.Info("Transforming manifest")
-	rbacProxyTranform, err := getRBACProxyInjectTransformer(r.client)
+	rbacProxyTranform, err := monitoring.GetRBACProxyInjectTransformer(r.client)
 	if err != nil {
 		return err
 	}
@@ -243,6 +251,7 @@ func (r *ReconcileKnativeKafka) transform(manifest *mf.Manifest, instance *opera
 		setAuthSecret(instance.Spec.Channel.AuthSecretNamespace, instance.Spec.Channel.AuthSecretName),
 		ImageTransform(common.BuildImageOverrideMapFromEnviron(os.Environ(), "KAFKA_IMAGE_"), log),
 		replicasTransform(manifest.Client),
+		configMapHashTransform(manifest.Client),
 		rbacProxyTranform,
 	)
 	if err != nil {
@@ -326,7 +335,7 @@ func isDeploymentAvailable(d *appsv1.Deployment) bool {
 
 // general clean-up. required for the resources that cannot be garbage collected with the owner reference mechanism
 func (r *ReconcileKnativeKafka) delete(instance *operatorv1alpha1.KnativeKafka) error {
-	defer common.KnativeUp.DeleteLabelValues("kafka_status")
+	defer monitoring.KnativeUp.DeleteLabelValues("kafka_status")
 	finalizers := sets.NewString(instance.GetFinalizers()...)
 
 	if !finalizers.Has(finalizerName) {
@@ -383,7 +392,7 @@ func (r *ReconcileKnativeKafka) buildManifest(instance *operatorv1alpha1.Knative
 	var resources []unstructured.Unstructured
 
 	if build == manifestBuildAll || (build == manifestBuildEnabledOnly && instance.Spec.Channel.Enabled) || (build == manifestBuildDisabledOnly && !instance.Spec.Channel.Enabled) {
-		channelRBACProxy, err := addRBACProxySupportToManifest(instance, kafkaChannelComponents)
+		channelRBACProxy, err := monitoring.AddRBACProxySupportToManifest(instance, monitoring.KafkaChannelComponents)
 		if err != nil {
 			return nil, err
 		}
@@ -392,12 +401,13 @@ func (r *ReconcileKnativeKafka) buildManifest(instance *operatorv1alpha1.Knative
 	}
 
 	if build == manifestBuildAll || (build == manifestBuildEnabledOnly && instance.Spec.Source.Enabled) || (build == manifestBuildDisabledOnly && !instance.Spec.Source.Enabled) {
-		sourceRBACProxy, err := addRBACProxySupportToManifest(instance, kafkaSourceComponents)
+		sourceRBACProxy, err := monitoring.AddRBACProxySupportToManifest(instance, monitoring.KafkaSourceComponents)
 		if err != nil {
 			return nil, err
 		}
 		resources = append(resources, sourceRBACProxy.Resources()...)
 		resources = append(resources, r.rawKafkaSourceManifest.Resources()...)
+		resources = append(resources, r.rawKafkaSourcePostInstallManifest.Resources()...)
 	}
 
 	manifest, err := mf.ManifestFrom(
@@ -455,6 +465,17 @@ func setKafkaDeployments(replicas int32) mf.Transformer {
 			if err := unstructured.SetNestedField(u.Object, int64(replicas), "spec", "replicas"); err != nil {
 				return err
 			}
+		} else if u.GetKind() == "HorizontalPodAutoscaler" {
+			min, _, err := unstructured.NestedInt64(u.Object, "spec", "minReplicas")
+			if err != nil {
+				return err
+			}
+			if min > int64(replicas) {
+				return nil
+			}
+			if err := unstructured.SetNestedField(u.Object, int64(replicas), "spec", "minReplicas"); err != nil {
+				return err
+			}
 		}
 		return nil
 	}
