@@ -6,17 +6,19 @@ import (
 	"os"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
-	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/dashboard"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/consoleclidownload"
-	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/kourier"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/quickstart"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/monitoring"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/monitoring/dashboards"
 	consolev1 "github.com/openshift/api/console/v1"
+	routev1 "github.com/openshift/api/route/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/sets"
 	servingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
@@ -25,6 +27,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 	"sigs.k8s.io/controller-runtime/pkg/handler"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
+	"sigs.k8s.io/controller-runtime/pkg/predicate"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 )
@@ -45,6 +48,8 @@ const (
 	// certVersionKey is an annotation key used by the Serverless operator to annotate the Knative Serving
 	// controller's PodTemplate to make it redeploy on certificate changes.
 	certVersionKey = "serving.knative.openshift.io/mounted-cert-version"
+
+	requiredNsEnvName = "REQUIRED_SERVING_NAMESPACE"
 )
 
 var log = common.Log.WithName("controller")
@@ -60,7 +65,7 @@ func newReconciler(mgr manager.Manager) reconcile.Reconciler {
 	client := mgr.GetClient()
 
 	// Create required namespace first.
-	if ns, required := os.LookupEnv("REQUIRED_SERVING_NAMESPACE"); required {
+	if ns, required := os.LookupEnv(requiredNsEnvName); required {
 		client.Create(context.Background(), &corev1.Namespace{ObjectMeta: metav1.ObjectMeta{
 			Name: ns,
 		}})
@@ -80,8 +85,14 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 		return err
 	}
 
-	// Watch for changes to primary resource KnativeServing
-	err = c.Watch(&source.Kind{Type: &servingv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{})
+	// Watch for changes to primary resource KnativeServing, only in the expected namespace.
+	requiredNs := os.Getenv(requiredNsEnvName)
+	err = c.Watch(&source.Kind{Type: &servingv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{}, predicate.NewPredicateFuncs(func(obj client.Object) bool {
+		if requiredNs == "" {
+			return true
+		}
+		return obj.GetNamespace() == requiredNs
+	}))
 	if err != nil {
 		return err
 	}
@@ -95,17 +106,10 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 		return err
 	}
 
-	// Load Kourier resources to watch them
-	kourierManifest, err := kourier.RawManifest(mgr.GetClient())
-	if err != nil {
-		return err
+	gvkToResource := map[schema.GroupVersionKind]client.Object{
+		consolev1.GroupVersion.WithKind("ConsoleCLIDownload"): &consolev1.ConsoleCLIDownload{},
+		routev1.GroupVersion.WithKind("Route"):                &routev1.Route{},
 	}
-
-	gvkToResource := common.BuildGVKToResourceMap(kourierManifest)
-
-	// append ConsoleCLIDownload type as well to Watch for kn CCD CO
-	gvkToResource[consolev1.GroupVersion.WithKind("ConsoleCLIDownload")] = &consolev1.ConsoleCLIDownload{}
-
 	for _, t := range gvkToResource {
 		err = c.Watch(&source.Kind{Type: t}, common.EnqueueRequestByOwnerAnnotations(common.ServingOwnerName, common.ServingOwnerNamespace))
 		if err != nil {
@@ -128,7 +132,7 @@ type ReconcileKnativeServing struct {
 }
 
 // Reconcile reads that state of the cluster for a KnativeServing
-func (r *ReconcileKnativeServing) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileKnativeServing) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	reqLogger := log.WithValues("Request.Namespace", request.Namespace, "Request.Name", request.Name)
 	reqLogger.Info("Reconciling KnativeServing")
 
@@ -155,11 +159,11 @@ func (r *ReconcileKnativeServing) Reconcile(request reconcile.Request) (reconcil
 		}
 	}
 
-	common.KnativeServingUpG = common.KnativeUp.WithLabelValues("serving_status")
+	monitoring.KnativeServingUpG = monitoring.KnativeUp.WithLabelValues("serving_status")
 	if instance.Status.IsReady() {
-		common.KnativeServingUpG.Set(1)
+		monitoring.KnativeServingUpG.Set(1)
 	} else {
-		common.KnativeServingUpG.Set(0)
+		monitoring.KnativeServingUpG.Set(0)
 	}
 	return reconcile.Result{}, reconcileErr
 }
@@ -169,9 +173,7 @@ func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *servingv1alp
 		r.configure,
 		r.ensureFinalizers,
 		r.ensureCustomCertsConfigMap,
-		r.installKourier,
 		r.installDashboard,
-		r.ensureProxySettings,
 		r.installQuickstarts,
 		r.installKnConsoleCLIDownload,
 	}
@@ -201,16 +203,6 @@ func (r *ReconcileKnativeServing) configure(instance *servingv1alpha1.KnativeSer
 	return nil
 }
 
-// ensureProxySettings updates the proxy settings on the KnativeServing controller.
-func (r *ReconcileKnativeServing) ensureProxySettings(instance *servingv1alpha1.KnativeServing) error {
-	proxyEnv := map[string]string{
-		"HTTP_PROXY":  os.Getenv("HTTP_PROXY"),
-		"HTTPS_PROXY": os.Getenv("HTTPS_PROXY"),
-		"NO_PROXY":    os.Getenv("NO_PROXY"),
-	}
-	return common.ApplyEnvironmentToDeployment(instance.Namespace, "controller", proxyEnv, r.client)
-}
-
 // set a finalizer to clean up service mesh when instance is deleted
 func (r *ReconcileKnativeServing) ensureFinalizers(instance *servingv1alpha1.KnativeServing) error {
 	for _, finalizer := range instance.GetFinalizers() {
@@ -282,7 +274,6 @@ func (r *ReconcileKnativeServing) ensureCustomCertsConfigMap(instance *servingv1
 	if err := r.client.Update(context.TODO(), controller); err != nil {
 		return fmt.Errorf("error updating the controller annotation: %w", err)
 	}
-
 	return nil
 }
 
@@ -338,22 +329,8 @@ func (r *ReconcileKnativeServing) reconcileConfigMap(instance *servingv1alpha1.K
 	return cm, nil
 }
 
-// Install Kourier Ingress Gateway
-func (r *ReconcileKnativeServing) installKourier(instance *servingv1alpha1.KnativeServing) error {
-	// install Kourier
-	if err := kourier.Apply(instance, r.client, r.scheme); err != nil {
-		instance.Status.MarkDependencyInstalling("Kourier")
-		return err
-	}
-	instance.Status.MarkDependenciesInstalled()
-	return nil
-}
-
 func (r *ReconcileKnativeServing) installQuickstarts(instance *servingv1alpha1.KnativeServing) error {
-	if err := quickstart.Apply(instance, r.client); err != nil {
-		return err
-	}
-	return nil
+	return quickstart.Apply(instance, r.client)
 }
 
 // installKnConsoleCLIDownload creates CR for kn CLI download link
@@ -363,12 +340,13 @@ func (r *ReconcileKnativeServing) installKnConsoleCLIDownload(instance *servingv
 
 // installDashboard installs dashboard for OpenShift webconsole
 func (r *ReconcileKnativeServing) installDashboard(instance *servingv1alpha1.KnativeServing) error {
-	return dashboard.Apply(os.Getenv(dashboard.ServingResourceDashboardPathEnvVar), instance, r.client)
+	log.Info("Installing Serving Dashboards")
+	return dashboards.Apply("serving", instance, r.client)
 }
 
 // general clean-up, mostly resources in different namespaces from servingv1alpha1.KnativeServing.
 func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServing) error {
-	defer common.KnativeUp.DeleteLabelValues("serving_status")
+	defer monitoring.KnativeUp.DeleteLabelValues("serving_status")
 	finalizers := sets.NewString(instance.GetFinalizers()...)
 
 	if !finalizers.Has(finalizerName) {
@@ -382,13 +360,8 @@ func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServin
 		return fmt.Errorf("failed to delete kn ConsoleCLIDownload: %w", err)
 	}
 
-	log.Info("Deleting kourier")
-	if err := kourier.Delete(instance, r.client, r.scheme); err != nil {
-		return fmt.Errorf("failed to delete kourier: %w", err)
-	}
-
-	log.Info("Deleting dashboard")
-	if err := dashboard.Delete(os.Getenv(dashboard.ServingResourceDashboardPathEnvVar), instance, r.client); err != nil {
+	log.Info("Deleting Serving dashboards")
+	if err := dashboards.Delete("serving", instance, r.client); err != nil {
 		return fmt.Errorf("failed to delete dashboard configmap: %w", err)
 	}
 
