@@ -17,10 +17,11 @@ create_namespaces
 install_catalogsource
 logger.success '🚀 Cluster prepared for testing.'
 
-# Need 6 worker nodes when running upgrade or upstream. Set, if not enough.
-if [[ "${SCALE_UP}" -lt 6 ]]; then
-  SCALE_UP=6
-  scale_up_workers
+scale_up_workers
+
+# Install ServiceMesh and enable mTLS.
+if [[ $FULL_MESH == true ]]; then
+  UNINSTALL_MESH="false" install_mesh
 fi
 
 # Run upgrade tests
@@ -31,11 +32,7 @@ if [[ $TEST_KNATIVE_UPGRADE == true ]]; then
     ensure_kafka_channel_default
   fi
   run_rolling_upgrade_tests
-  trigger_gc_and_print_knative
-  # Call teardown only if E2E tests follow.
-  if [[ $TEST_KNATIVE_E2E == true ]]; then
-    teardown_serverless
-  fi
+  teardown_serverless
 fi
 
 # Run upstream knative serving, eventing and eventing-kafka tests
